@@ -1,3 +1,4 @@
+import uuid
 from django.contrib.auth import get_user_model
 from django.conf import settings
 from django.db import models
@@ -91,8 +92,12 @@ class CommunityJobOffer(Model):
 
 @receiver(pre_save, sender=Community)
 def pre_create_account(sender, instance, **kwargs):
-    if getattr(instance, Model.slug_field(instance)) != slugify(instance.name):
-        if Community.objects.filter(slug=slugify(instance.name)).count() > 0:
-            raise Exception(_("Name already taken"))
-        setattr(instance, Model.slug_field(instance), slugify(instance.name))
+    if instance.urlid.startswith(settings.SITE_URL):
+        if getattr(instance, Model.slug_field(instance)) != slugify(instance.name):
+            if Community.objects.filter(slug=slugify(instance.name)).count() > 0:
+                raise Exception(_("Name already taken"))
+            setattr(instance, Model.slug_field(instance), slugify(instance.name))
+    else:
+        # Is a distant object, generate a random slug
+        setattr(instance, Model.slug_field(instance), uuid.uuid4().hex.upper()[0:8])
 
